@@ -45,6 +45,37 @@
 #define GNOME_SESSION_MANAGER_PATH		"/org/gnome/SessionManager"
 #define GNOME_SESSION_MANAGER_INTERFACE		"org.gnome.SessionManager"
 
+/* if the dialog is going to cover more than this much of the screen, then maximise it at startup */
+#define GPK_SMALL_FORM_FACTOR_SCREEN_PERCENT	75 /* % */
+
+/* static, so local to process */
+static gboolean small_form_factor_mode = FALSE;
+
+#if (!PK_CHECK_VERSION(0,5,0))
+/**
+ * gpk_error_code_is_need_untrusted:
+ * @error_code: the transactions #PkErrorCodeEnum
+ *
+ * Return value: if the error code suggests to try with only_trusted %FALSE
+ **/
+gboolean
+gpk_error_code_is_need_untrusted (PkErrorCodeEnum error_code)
+{
+	gboolean ret = FALSE;
+	switch (error_code) {
+		case PK_ERROR_ENUM_GPG_FAILURE:
+		case PK_ERROR_ENUM_BAD_GPG_SIGNATURE:
+		case PK_ERROR_ENUM_MISSING_GPG_SIGNATURE:
+		case PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED:
+		case PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED:
+			ret = TRUE;
+			break;
+		default:
+			break;
+	}
+	return ret;
+}
+#endif
 
 /**
  * gtk_text_buffer_insert_markup:
@@ -170,45 +201,12 @@ gtk_text_buffer_insert_markup (GtkTextBuffer *buffer, GtkTextIter *iter, const g
 }
 
 /**
- * gpk_session_logout:
+ * gpk_window_get_small_form_factor_mode:
  **/
 gboolean
-gpk_session_logout (void)
+gpk_window_get_small_form_factor_mode (void)
 {
-	DBusGConnection *connection;
-	DBusGProxy *proxy = NULL;
-	gboolean ret = FALSE;
-	GError *error = NULL;
-
-	/* connect to DBus */
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
-	if (connection == NULL) {
-		egg_warning ("Failed to connect to DBus: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* connect to SessionManager */
-	proxy = dbus_g_proxy_new_for_name (connection, GNOME_SESSION_MANAGER_NAME,
-					   GNOME_SESSION_MANAGER_PATH,
-					   GNOME_SESSION_MANAGER_INTERFACE);
-	if (proxy == NULL) {
-		egg_warning ("cannot connect to session manager");
-		goto out;
-	}
-	ret = dbus_g_proxy_call (proxy, "Logout", &error,
-				 G_TYPE_UINT, 0,
-				 G_TYPE_INVALID,
-				 G_TYPE_INVALID);
-	if (!ret) {
-		egg_warning ("Failed to logout: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
-	if (proxy != NULL)
-		g_object_unref (proxy);
-	return ret;
+	return small_form_factor_mode;
 }
 
 /**
@@ -220,24 +218,59 @@ gpk_window_set_size_request (GtkWindow *window, guint width, guint height)
 	GdkScreen *screen;
 	guint screen_w;
 	guint screen_h;
+	guint percent_w;
+	guint percent_h;
 
 	/* check for tiny screen, like for instance a OLPC or EEE */
 	screen = gdk_screen_get_default ();
 	screen_w = gdk_screen_get_width (screen);
 	screen_h = gdk_screen_get_height (screen);
-	if (screen_w < width || screen_h < height) {
+
+	/* find percentage of screen area */
+	percent_w = (width * 100) / screen_w;
+	percent_h = (height * 100) / screen_h;
+	egg_debug ("window coverage x:%i%% y:%i%%", percent_w, percent_h);
+
+	if (percent_w > GPK_SMALL_FORM_FACTOR_SCREEN_PERCENT ||
+	    percent_h > GPK_SMALL_FORM_FACTOR_SCREEN_PERCENT) {
 		egg_debug ("using small form factor mode as %ix%i and requested %ix%i",
 			   screen_w, screen_h, width, height);
 		gtk_window_maximize (window);
-		return FALSE;
+		small_form_factor_mode = TRUE;
+		goto out;
 	}
 
 	/* normal size laptop panel */
 	egg_debug ("using native mode: %ix%i", width, height);
 	gtk_window_set_default_size (window, width, height);
+	small_form_factor_mode = FALSE;
+out:
+	return !small_form_factor_mode;
+}
+
+/**
+ * gpk_window_set_parent_xid:
+ **/
+gboolean
+gpk_window_set_parent_xid (GtkWindow *window, guint32 xid)
+{
+	GdkDisplay *display;
+	GdkWindow *parent_window;
+	GdkWindow *our_window;
+
+	g_return_val_if_fail (xid != 0, FALSE);
+
+	display = gdk_display_get_default ();
+	parent_window = gdk_window_foreign_new_for_display (display, xid);
+	our_window = gtk_widget_get_window (GTK_WIDGET (window));
+
+	/* set this above our parent */
+	gtk_window_set_modal (window, TRUE);
+	gdk_window_set_transient_for (our_window, parent_window);
 	return TRUE;
 }
 
+
 /**
  * gpk_package_id_format_twoline:
  *
