@@ -27,49 +27,50 @@
 #include <packagekit-glib/packagekit.h>
 
 #include "gpk-animated-icon.h"
+#include "gpk-enum.h"
 
 G_BEGIN_DECLS
 
 #define GPK_CONF_DIR				"/apps/gnome-packagekit"
-#define GPK_CONF_NOTIFY_COMPLETED		"/apps/gnome-packagekit/notify_complete"
-#define GPK_CONF_NOTIFY_AVAILABLE		"/apps/gnome-packagekit/notify_available"
-#define GPK_CONF_NOTIFY_DISTRO_UPGRADES		"/apps/gnome-packagekit/notify_distro_upgrades"
-#define GPK_CONF_NOTIFY_CRITICAL		"/apps/gnome-packagekit/notify_critical"
-#define GPK_CONF_NOTIFY_ERROR			"/apps/gnome-packagekit/notify_errors"
-#define GPK_CONF_NOTIFY_MESSAGE			"/apps/gnome-packagekit/notify_message"
-#define GPK_CONF_NOTIFY_UPDATE_STARTED		"/apps/gnome-packagekit/notify_update_started"
-#define GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY	"/apps/gnome-packagekit/notify_update_not_battery"
-#define GPK_CONF_NOTIFY_UPDATE_FAILED		"/apps/gnome-packagekit/notify_update_failed"
-#define GPK_CONF_NOTIFY_UPDATE_COMPLETE		"/apps/gnome-packagekit/notify_update_complete"
-#define GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART	"/apps/gnome-packagekit/notify_update_complete_restart"
-#define GPK_CONF_CONNECTION_USE_MOBILE		"/apps/gnome-packagekit/connection_use_mobile"
-#define GPK_CONF_CONNECTION_USE_WIFI		"/apps/gnome-packagekit/connection_use_wifi"
 #define GPK_CONF_AUTOCOMPLETE			"/apps/gnome-packagekit/autocomplete"
-#define GPK_CONF_SESSION_STARTUP_TIMEOUT	"/apps/gnome-packagekit/session_startup_timeout"
-#define GPK_CONF_FORCE_GET_UPDATES_LOGIN	"/apps/gnome-packagekit/force_get_updates_login"
-#define GPK_CONF_FREQUENCY_GET_UPDATES		"/apps/gnome-packagekit/frequency_get_updates"
-#define GPK_CONF_FREQUENCY_GET_UPGRADES		"/apps/gnome-packagekit/frequency_get_upgrades"
-#define GPK_CONF_FREQUENCY_REFRESH_CACHE	"/apps/gnome-packagekit/frequency_refresh_cache"
-#define GPK_CONF_AUTO_UPDATE			"/apps/gnome-packagekit/auto_update"
-#define GPK_CONF_UPDATE_BATTERY			"/apps/gnome-packagekit/update_battery"
 #define GPK_CONF_SHOW_DEPENDS			"/apps/gnome-packagekit/show_depends"
 #define GPK_CONF_SHOW_COPY_CONFIRM		"/apps/gnome-packagekit/show_copy_confirm"
-#define GPK_CONF_BANNED_FIRMWARE		"/apps/gnome-packagekit/banned_firmware"
 #define GPK_CONF_DBUS_DEFAULT_INTERACTION	"/apps/gnome-packagekit/dbus_default_interaction"
 #define GPK_CONF_DBUS_ENFORCED_INTERACTION	"/apps/gnome-packagekit/dbus_enforced_interaction"
-#define GPK_CONF_REPO_SHOW_DETAILS		"/apps/gnome-packagekit/repo/show_details"
-#define GPK_CONF_APPLICATION_FILTER_BASENAME	"/apps/gnome-packagekit/application/filter_basename"
-#define GPK_CONF_APPLICATION_FILTER_NEWEST	"/apps/gnome-packagekit/application/filter_newest"
-#define GPK_CONF_APPLICATION_CATEGORY_GROUPS	"/apps/gnome-packagekit/application/category_groups"
-#define GPK_CONF_APPLICATION_SEARCH_MODE	"/apps/gnome-packagekit/application/search_mode"
-#define GPK_CONF_UPDATE_VIEWER_MOBILE_BBAND	"/apps/gnome-packagekit/update-viewer/notify_mobile_connection"
-#define GPK_CONF_IGNORED_MESSAGES		"/apps/gnome-packagekit/ignored_messages"
-
 #define GPK_CONF_ENABLE_FONT_HELPER		"/apps/gnome-packagekit/enable_font_helper"
 #define GPK_CONF_ENABLE_CODEC_HELPER		"/apps/gnome-packagekit/enable_codec_helper"
 #define GPK_CONF_ENABLE_MIME_TYPE_HELPER	"/apps/gnome-packagekit/enable_mime_type_helper"
 #define GPK_CONF_ENABLE_CHECK_FIRMWARE		"/apps/gnome-packagekit/enable_check_firmware"
 #define GPK_CONF_ENABLE_CHECK_HARDWARE		"/apps/gnome-packagekit/enable_check_hardware"
+#define GPK_CONF_REPO_SHOW_DETAILS		"/apps/gnome-packagekit/repo/show_details"
+#define GPK_CONF_CONNECTION_USE_MOBILE		"/apps/gnome-packagekit/update-icon/connection_use_mobile"
+#define GPK_CONF_CONNECTION_USE_WIFI		"/apps/gnome-packagekit/update-icon/connection_use_wifi"
+#define GPK_CONF_NOTIFY_COMPLETED		"/apps/gnome-packagekit/update-icon/notify_complete"
+#define GPK_CONF_NOTIFY_AVAILABLE		"/apps/gnome-packagekit/update-icon/notify_available"
+#define GPK_CONF_NOTIFY_DISTRO_UPGRADES		"/apps/gnome-packagekit/update-icon/notify_distro_upgrades"
+#define GPK_CONF_NOTIFY_CRITICAL		"/apps/gnome-packagekit/update-icon/notify_critical"
+#define GPK_CONF_NOTIFY_ERROR			"/apps/gnome-packagekit/update-icon/notify_errors"
+#define GPK_CONF_NOTIFY_MESSAGE			"/apps/gnome-packagekit/update-icon/notify_message"
+#define GPK_CONF_NOTIFY_UPDATE_STARTED		"/apps/gnome-packagekit/update-icon/notify_update_started"
+#define GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY	"/apps/gnome-packagekit/update-icon/notify_update_not_battery"
+#define GPK_CONF_NOTIFY_UPDATE_FAILED		"/apps/gnome-packagekit/update-icon/notify_update_failed"
+#define GPK_CONF_NOTIFY_UPDATE_COMPLETE		"/apps/gnome-packagekit/update-icon/notify_update_complete"
+#define GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART	"/apps/gnome-packagekit/update-icon/notify_update_complete_restart"
+#define GPK_CONF_SESSION_STARTUP_TIMEOUT	"/apps/gnome-packagekit/update-icon/session_startup_timeout"
+#define GPK_CONF_FORCE_GET_UPDATES_LOGIN	"/apps/gnome-packagekit/update-icon/force_get_updates_login"
+#define GPK_CONF_FREQUENCY_GET_UPDATES		"/apps/gnome-packagekit/update-icon/frequency_get_updates"
+#define GPK_CONF_FREQUENCY_GET_UPGRADES		"/apps/gnome-packagekit/update-icon/frequency_get_upgrades"
+#define GPK_CONF_FREQUENCY_REFRESH_CACHE	"/apps/gnome-packagekit/update-icon/frequency_refresh_cache"
+#define GPK_CONF_AUTO_UPDATE			"/apps/gnome-packagekit/update-icon/auto_update"
+#define GPK_CONF_UPDATE_BATTERY			"/apps/gnome-packagekit/update-icon/update_battery"
+#define GPK_CONF_BANNED_FIRMWARE		"/apps/gnome-packagekit/update-icon/banned_firmware"
+#define GPK_CONF_IGNORED_MESSAGES		"/apps/gnome-packagekit/update-icon/ignored_messages"
+#define GPK_CONF_WATCH_ACTIVE_TRANSACTIONS	"/apps/gnome-packagekit/update-icon/watch_active_transactions"
+#define GPK_CONF_APPLICATION_FILTER_BASENAME	"/apps/gnome-packagekit/application/filter_basename"
+#define GPK_CONF_APPLICATION_FILTER_NEWEST	"/apps/gnome-packagekit/application/filter_newest"
+#define GPK_CONF_APPLICATION_CATEGORY_GROUPS	"/apps/gnome-packagekit/application/category_groups"
+#define GPK_CONF_APPLICATION_SEARCH_MODE	"/apps/gnome-packagekit/application/search_mode"
+#define GPK_CONF_UPDATE_VIEWER_MOBILE_BBAND	"/apps/gnome-packagekit/update-viewer/notify_mobile_connection"
 
 #define GPK_BUGZILLA_URL			"https://bugs.freedesktop.org/"
 
@@ -104,8 +105,13 @@ GtkEntryCompletion *gpk_package_entry_completion_new	(void);
 gboolean	 gpk_window_set_size_request		(GtkWindow	*window,
 							 guint		 width,
 							 guint		 height);
-gboolean	 gpk_session_logout			(void);
 gboolean	 gpk_ignore_session_error		(GError		*error);
+gboolean	 gpk_window_get_small_form_factor_mode 	(void);
+gboolean	 gpk_window_set_parent_xid		(GtkWindow	*window,
+							 guint32	 xid);
+#if (!PK_CHECK_VERSION(0,5,0))
+gboolean	 gpk_error_code_is_need_untrusted	(PkErrorCodeEnum error_code);
+#endif
 
 G_END_DECLS
 
