@@ -582,7 +582,11 @@ gpk_log_refresh (void)
 	/* get the list */
 	if (transactions != NULL)
 		g_object_unref (transactions);
-	transactions = pk_client_get_cached_objects (client);
+#if PK_CHECK_VERSION(0,5,0)
+	transactions = pk_client_get_transaction_list (client);
+#else
+	transactions = pk_client_get_cached_objects (client); /* removed in 0.5.x */
+#endif
 	gpk_log_refilter ();
 out:
 	return ret;
@@ -634,6 +638,7 @@ main (int argc, char *argv[])
 	UniqueApp *unique_app;
 	gboolean ret;
 	guint retval;
+	guint xid = 0;
 	GError *error = NULL;
 
 	const GOptionEntry options[] = {
@@ -642,6 +647,9 @@ main (int argc, char *argv[])
 		{ "filter", 'f', 0, G_OPTION_ARG_STRING, &filter,
 		  /* TRANSLATORS: preset the GtktextBox with this filter text */
 		  N_("Set the filter to this value"), NULL },
+		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
+		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
+		  _("Set the parent window to make this modal"), NULL },
 		{ NULL}
 	};
 
@@ -743,7 +751,6 @@ main (int argc, char *argv[])
 		g_object_unref (completion);
 	} else {
 		/* use search as you type */
-		g_signal_connect (widget, "key-press-event", G_CALLBACK (gpk_log_entry_filter_cb), NULL);
 		g_signal_connect (widget, "key-release-event", G_CALLBACK (gpk_log_entry_filter_cb), NULL);
 	}
 	g_object_unref (gconf_client);
@@ -774,6 +781,13 @@ main (int argc, char *argv[])
 	/* show */
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_simple"));
 	gtk_widget_show (widget);
+
+	/* set the parent window if it is specified */
+	if (xid != 0) {
+		egg_debug ("Setting xid %i", xid);
+		gpk_window_set_parent_xid (GTK_WINDOW (widget), xid);
+	}
+
 	gtk_main ();
 
 out_build:
